[doxygen] Review fixes.

- Move directory back to docs
- Move doxygen-format-check.sh to scripts/helpers.
- Clean up CHIP naming.
diff --git a/Makefile.am b/Makefile.am
index d47ec74..70adde8 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -34,7 +34,7 @@
     examples                               \
     third_party                            \
     src                                    \
-    doc                                    \
+    docs                                   \
     tests                                  \
     $(NULL)
 
@@ -212,7 +212,7 @@
 
 .PHONY: docdist
 docdist: $(BUILT_SOURCES)
-	$(MAKE) -C doc docdistdir=$(abs_builddir) $(@)
+	$(MAKE) -C docs docdistdir=$(abs_builddir) $(@)
 
 #
 # Top-level convenience target for making a tools-only distribution
diff --git a/configure.ac b/configure.ac
index 9160b4a..e5ececd 100644
--- a/configure.ac
+++ b/configure.ac
@@ -2080,7 +2080,7 @@
 src/lib/support/tests/Makefile
 src/platform/Makefile
 tests/Makefile
-doc/Makefile
+docs/Makefile
 ])
 
 #
diff --git a/doc/BUILDING.md b/docs/BUILDING.md
similarity index 100%
rename from doc/BUILDING.md
rename to docs/BUILDING.md
diff --git a/doc/ChipDoxygenLayout.xml b/docs/ChipDoxygenLayout.xml
similarity index 100%
rename from doc/ChipDoxygenLayout.xml
rename to docs/ChipDoxygenLayout.xml
diff --git a/doc/Doxyfile.in b/docs/Doxyfile.in
similarity index 99%
rename from doc/Doxyfile.in
rename to docs/Doxyfile.in
index f00ed0c..ca3e67f 100644
--- a/doc/Doxyfile.in
+++ b/docs/Doxyfile.in
@@ -914,7 +914,7 @@
 # code is scanned, but not when the output code is generated. If lines are added
 # or removed, the anchors will not be placed correctly.
 
-INPUT_FILTER           = @abs_srcdir@/format-file.sh
+INPUT_FILTER           = @abs_top_srcdir@/scripts/helpers/doxygen-format-check.sh
 
 # The FILTER_PATTERNS tag can be used to specify filters on a per file pattern
 # basis. Doxygen will compare the file name with each pattern and apply the
diff --git a/doc/Makefile.am b/docs/Makefile.am
similarity index 89%
rename from doc/Makefile.am
rename to docs/Makefile.am
index 1c5902d..668b26b 100644
--- a/doc/Makefile.am
+++ b/docs/Makefile.am
@@ -18,17 +18,17 @@
 
 #
 #    Description:
-#      This file is the GNU automake template for the Nest Weave
+#      This file is the GNU automake template for the CHIP
 #      API and stack documentation.
 #
 
 include $(abs_top_nlbuild_autotools_dir)/automake/pre.am
 
-EXTRA_DIST                                      = \
-    $(srcdir)/Doxyfile.in                         \
-    $(srcdir)/ChipDoxygenLayout.xml              \
-    $(srcdir)/format-file.sh                      \
-    $(srcdir)/namespaces.dox                      \
+EXTRA_DIST                                                = \
+    $(srcdir)/Doxyfile.in                                   \
+    $(srcdir)/ChipDoxygenLayout.xml                         \
+     $(top_srcdir)/scripts/helpers/doxygen-format-check.sh  \
+    $(srcdir)/namespaces.dox                                \
     $(NULL)
 
 #
@@ -88,7 +88,7 @@
 
 #
 # Addition rules and commands to create a documentation-only
-# distribution of Weave
+# distribution of Chip
 #
 
 $(chip_docdist_name): $(EXTRA_DOCS) html/index.html
diff --git a/doc/PROJECT_FLOW.md b/docs/PROJECT_FLOW.md
similarity index 100%
rename from doc/PROJECT_FLOW.md
rename to docs/PROJECT_FLOW.md
diff --git a/doc/README.md b/docs/README.md
similarity index 100%
rename from doc/README.md
rename to docs/README.md
diff --git a/doc/STYLE_GUIDE.md b/docs/STYLE_GUIDE.md
similarity index 100%
rename from doc/STYLE_GUIDE.md
rename to docs/STYLE_GUIDE.md
diff --git a/doc/VSCODE_DEVELOPMENT.md b/docs/VSCODE_DEVELOPMENT.md
similarity index 100%
rename from doc/VSCODE_DEVELOPMENT.md
rename to docs/VSCODE_DEVELOPMENT.md
diff --git a/doc/namespaces.dox b/docs/namespaces.dox
similarity index 64%
rename from doc/namespaces.dox
rename to docs/namespaces.dox
index 55ae43c..1cec128 100644
--- a/doc/namespaces.dox
+++ b/docs/namespaces.dox
@@ -19,28 +19,19 @@
 
 /*
  *    Description:
- *      This file documents all C++ namespaces used within the Weave
+ *      This file documents all C++ namespaces used within the CHIP
  *      Core SDK that are not otherwise documented in an umbrella
  *      header encompassing that namespace.
  *
  */
 
 /**
- *   @namespace nl
+ *   @namespace chip
  *
  *   @brief
- *     This namespace is the outermost namespace for all Weave interfaces.
+ *     This namespace is the outermost namespace for all CHIP interfaces.
  *
- *     @note All Nest Labs interfaces shall appear within this namespace.
- *
- *     @note No third-party interfaces shall appear within this namespace.
- */
-
-/**
- *   @namespace nl::Weave
- *
- *   @brief
- *     This namespace includes interfaces within the Weave Core SDK
- *     that cover the Core stack, the Common and Nest vendor-specific
+ *     This namespace includes interfaces within the CHIP Core SDK
+ *     that cover the Core stack, the Common and vendor-specific
  *     profiles, and the support interfaces.
  */
diff --git a/doc/specs/chip-tlv-format.adoc b/docs/specs/chip-tlv-format.adoc
similarity index 100%
rename from doc/specs/chip-tlv-format.adoc
rename to docs/specs/chip-tlv-format.adoc
diff --git a/doc/style/README.md b/docs/style/README.md
similarity index 100%
rename from doc/style/README.md
rename to docs/style/README.md
diff --git a/doc/style/STYLE_MAKEFILES.md b/docs/style/STYLE_MAKEFILES.md
similarity index 100%
rename from doc/style/STYLE_MAKEFILES.md
rename to docs/style/STYLE_MAKEFILES.md
diff --git a/doc/format-file.sh b/scripts/helpers/doxygen-format-check.sh
similarity index 79%
rename from doc/format-file.sh
rename to scripts/helpers/doxygen-format-check.sh
index b7490a4..c7ff308 100755
--- a/doc/format-file.sh
+++ b/scripts/helpers/doxygen-format-check.sh
@@ -18,7 +18,7 @@
 #    limitations under the License.
 #
 
 # Managed namespace constructs within Weave ended up seriously
 # confusing Doxygen, and I could not find a nicer way to evaluate
 # those macros via Doxygen's PREDEFINED directives.  Instead, we
 # process the incoming files via this script file.
@@ -26,11 +26,11 @@
 SED=/bin/sed
 FILENAME=${1}
 # clang format has difficulty recognizing the
-# WeaveMakeManagedNamespaceIdentifier() macro as a valid namespace;
+# ChipMakeManagedNamespaceIdentifier() macro as a valid namespace;
 # temporarily change the namespace name to something more palatable to
 # clang-format
 
-sed -e 's:^[ 	]*namespace[ 	]\+WeaveMakeManagedNamespaceIdentifier(\([^ 	,()]\+\),[ 	]*kWeaveManagedNamespaceDesignation_\([^ 	,()]\+\))[ 	]*{[ 	]*$:namespace \1_\2 {:g' \
+sed -e 's:^[ 	]*namespace[ 	]\+ChipMakeManagedNamespaceIdentifier(\([^ 	,()]\+\),[ 	]*kChipManagedNamespaceDesignation_\([^ 	,()]\+\))[ 	]*{[ 	]*$:namespace \1_\2 {:g' \
   -e 's/NS_ENUM(\([_a-zA-Z0-9][_a-zA-Z0-9]*\)[ 	]*,[ 	]*\([_a-zA-Z0-9][_a-zA-Z0-9]*\))/ enum \2 : \1 \2; enum \2 : \1/g' \
   -e 's/__attribute__(([^)]*))//g' \
   -e 's/__attribute__([^)]*)//g' "$FILENAME"
@@ -18,7 +18,7 @@
 #
 
-# Managed namespace constructs within Weave ended up seriously
+# Managed namespace constructs within CHIP ended up seriously
 # confusing Doxygen, and I could not find a nicer way to evaluate
 # those macros via Doxygen's PREDEFINED directives.  Instead, we